#define Version "31-07-2015 a"
#define OLED
#define OLED_Socket2
/*
 * Project name:
      OLED C Click
 * Copyright: V.O.(c) mikroElektronika, 2014.
 * Revision History:
      20140919:  Initial release (BD) fot 18F45K22
      Adapatation au 18F87J50 par Paulfjujo 150731
 * Description:
      OLED C click lets you add a small but bright and crisp display to your design. 
      It carries a passive matrix OLED display capable of displaying over 65k colors,
      and a SEPS114A display driver and controller IC.
      OLED C click communicates with the target board through mikroBUS SPI lines:
      CS, SCK, and MOSI (SDI); and PWM (A/C) and RST lines.
      They are bright, have a wide viewing angle and low power consumption (with a 20mA maximum).
      The display on OLED C click is 19.8 x 19.8mm with a 96 x 96px resolution.
      The SEPS114A controller has built-in functionalities like screen saver (vertical scroll, horizontal panning, fade in/out), 
      programmable panel size, power save mode and so forth.

 * Test configuration:
      MCU:             PIC18F87J50
      Dev. Board:      Clicker2 PIC18F87J50
      Oscillator:      HS-PLL, 8MHz Crystal, 48MHz MCU Clock
      ext. modules:    OLED C click   96x96 65K colors SEPS114A display driver
                       uses a 3.3V power supply.
      SW:              mikroC PRO 6.50 for PIC
      Nota : Pas d'EEPROM sur ce PIC !
      
      Test OK sur mikrobus click #2
      
CONFIG1L : $1FFF8 : 0x00AC
CONFIG1H : $1FFF9 : 0x00F7
CONFIG2L : $1FFFA : 0x00C5
CONFIG2H : $1FFFB : 0x00FF
CONFIG3L : $1FFFC : 0x00F8
CONFIG3H : $1FFFD : 0x00FF



 NOTES:
     - Place OLED C Click board in the mikroBUS socket 2. , because use of RA0 as analog
*/

#include "Oled_C_18FJ.h"

 //-- commandes terminal VT220
#define CLS 12     // effacement de page sur Terminal VBRAY
#define CR 13
#define VT 10
#define LF 10
#define TAB 9
#define Bell 7
#define Byte unsigned char
#define uint8 unsigned char


// USB RAM Area
unsigned char readbuff[64] absolute 0x500;
unsigned char writebuff[64] absolute 0x540;

#ifdef OLED_Socket1
sbit OLED_RW at LATA0_bit;  // AN   Sockect 1
sbit OLED_RST at LATD2_bit; // RST  Sockect 1
sbit OLED_CS at LATD3_bit;  // CS   Sockect 1
sbit OLED_DC at LATG3_bit;  // 0=D=Data  1=C=Cde  Sockect 1

sbit OLED_RW_Direction at TRISA0_bit;
sbit OLED_RST_Direction at TRISD2_bit;
sbit OLED_CS_Direction  at TRISD3_bit;
sbit OLED_DC_Direction  at TRISG3_bit;   // Sockect 1
#endif

#ifdef OLED_Socket2
sbit OLED_RW  at LATA1_bit;  // AN   Sockect 2
sbit OLED_RST at LATD0_bit; // RST  Sockect 2
sbit OLED_CS  at LATD1_bit;  // CS   Sockect 2
sbit OLED_DC  at LATG0_bit;  // Data/Command 0=D=Data  1=C=Cde  Sockect 2

sbit OLED_RW_Direction at TRISA1_bit;
sbit OLED_RST_Direction at TRISD0_bit;
sbit OLED_CS_Direction  at TRISD1_bit;
sbit OLED_DC_Direction  at TRISG0_bit;   // Sockect 1
#endif

// specific Hardware on  Clicker2 PIC18F87J50 board
sbit LD1 at LATD4_bit;
sbit LD2 at LATE4_bit;
sbit LD1_Direction at TRISD4_bit;
sbit LD2_Direction at TRISE4_bit;

sbit BP1 at RD7_bit;
sbit BP2 at RH3_bit;
sbit BP1_Direction at TRISD7_bit;
sbit BP2_Direction at TRISH3_bit;


const unsigned char font_regular[92][6] =
{
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   // sp
    0x00, 0x00, 0x00, 0x2f, 0x00, 0x00,   // !
    0x00, 0x00, 0x07, 0x00, 0x07, 0x00,   // "
    0x00, 0x14, 0x7f, 0x14, 0x7f, 0x14,   // #
    0x00, 0x24, 0x2a, 0x7f, 0x2a, 0x12,   // $
    0x00, 0x62, 0x64, 0x08, 0x13, 0x23,   // %
    0x00, 0x36, 0x49, 0x55, 0x22, 0x50,   // &
    0x00, 0x00, 0x05, 0x03, 0x00, 0x00,   // '
    0x00, 0x00, 0x1c, 0x22, 0x41, 0x00,   // (
    0x00, 0x00, 0x41, 0x22, 0x1c, 0x00,   // )
    0x00, 0x14, 0x08, 0x3E, 0x08, 0x14,   // *
    0x00, 0x08, 0x08, 0x3E, 0x08, 0x08,   // +
    0x00, 0x00, 0x00, 0xA0, 0x60, 0x00,   // ,
    0x00, 0x08, 0x08, 0x08, 0x08, 0x08,   // -
    0x00, 0x00, 0x60, 0x60, 0x00, 0x00,   // .
    0x00, 0x20, 0x10, 0x08, 0x04, 0x02,   // /
    0x00, 0x3E, 0x51, 0x49, 0x45, 0x3E,   // 0
    0x00, 0x00, 0x42, 0x7F, 0x40, 0x00,   // 1
    0x00, 0x42, 0x61, 0x51, 0x49, 0x46,   // 2
    0x00, 0x21, 0x41, 0x45, 0x4B, 0x31,   // 3
    0x00, 0x18, 0x14, 0x12, 0x7F, 0x10,   // 4
    0x00, 0x27, 0x45, 0x45, 0x45, 0x39,   // 5
    0x00, 0x3C, 0x4A, 0x49, 0x49, 0x30,   // 6
    0x00, 0x01, 0x71, 0x09, 0x05, 0x03,   // 7
    0x00, 0x36, 0x49, 0x49, 0x49, 0x36,   // 8
    0x00, 0x06, 0x49, 0x49, 0x29, 0x1E,   // 9
    0x00, 0x00, 0x36, 0x36, 0x00, 0x00,   // :
    0x00, 0x00, 0x56, 0x36, 0x00, 0x00,   // ;
    0x00, 0x08, 0x14, 0x22, 0x41, 0x00,   // <
    0x00, 0x14, 0x14, 0x14, 0x14, 0x14,   // =
    0x00, 0x00, 0x41, 0x22, 0x14, 0x08,   // >
    0x00, 0x02, 0x01, 0x51, 0x09, 0x06,   // ?
    0x00, 0x32, 0x49, 0x59, 0x51, 0x3E,   // @
    0x00, 0x7C, 0x12, 0x11, 0x12, 0x7C,   // A
    0x00, 0x7F, 0x49, 0x49, 0x49, 0x36,   // B
    0x00, 0x3E, 0x41, 0x41, 0x41, 0x22,   // C
    0x00, 0x7F, 0x41, 0x41, 0x22, 0x1C,   // D
    0x00, 0x7F, 0x49, 0x49, 0x49, 0x41,   // E
    0x00, 0x7F, 0x09, 0x09, 0x09, 0x01,   // F
    0x00, 0x3E, 0x41, 0x49, 0x49, 0x7A,   // G
    0x00, 0x7F, 0x08, 0x08, 0x08, 0x7F,   // H
    0x00, 0x00, 0x41, 0x7F, 0x41, 0x00,   // I
    0x00, 0x20, 0x40, 0x41, 0x3F, 0x01,   // J
    0x00, 0x7F, 0x08, 0x14, 0x22, 0x41,   // K
    0x00, 0x7F, 0x40, 0x40, 0x40, 0x40,   // L
    0x00, 0x7F, 0x02, 0x0C, 0x02, 0x7F,   // M
    0x00, 0x7F, 0x04, 0x08, 0x10, 0x7F,   // N
    0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E,   // O
    0x00, 0x7F, 0x09, 0x09, 0x09, 0x06,   // P
    0x00, 0x3E, 0x41, 0x51, 0x21, 0x5E,   // Q
    0x00, 0x7F, 0x09, 0x19, 0x29, 0x46,   // R
    0x00, 0x46, 0x49, 0x49, 0x49, 0x31,   // S
    0x00, 0x01, 0x01, 0x7F, 0x01, 0x01,   // T
    0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F,   // U
    0x00, 0x1F, 0x20, 0x40, 0x20, 0x1F,   // V
    0x00, 0x3F, 0x40, 0x38, 0x40, 0x3F,   // W
    0x00, 0x63, 0x14, 0x08, 0x14, 0x63,   // X
    0x00, 0x07, 0x08, 0x70, 0x08, 0x07,   // Y
    0x00, 0x61, 0x51, 0x49, 0x45, 0x43,   // Z
    0x00, 0x00, 0x7F, 0x41, 0x41, 0x00,   // [ 91
    0x00, 0x02, 0x04 , 0x08, 0x10, 0x20,    // \92
    0x00, 0x00, 0x41, 0x41, 0x7F, 0x00,   // ]
    0x00, 0x04, 0x02, 0x01, 0x02, 0x04,   // ^
    0x00, 0x40, 0x40, 0x40, 0x40, 0x40,   // _
    0x00, 0x00, 0x01, 0x02, 0x04, 0x00,   // '
    0x00, 0x20, 0x54, 0x54, 0x54, 0x78,   // a
    0x00, 0x7F, 0x48, 0x44, 0x44, 0x38,   // b
    0x00, 0x38, 0x44, 0x44, 0x44, 0x20,   // c
    0x00, 0x38, 0x44, 0x44, 0x48, 0x7F,   // d
    0x00, 0x38, 0x54, 0x54, 0x54, 0x18,   // e
    0x00, 0x08, 0x7E, 0x09, 0x01, 0x02,   // f
    0x00, 0x18, 0xA4, 0xA4, 0xA4, 0x7C,   // g
    0x00, 0x7F, 0x08, 0x04, 0x04, 0x78,   // h
    0x00, 0x00, 0x44, 0x7D, 0x40, 0x00,   // i
    0x00, 0x40, 0x80, 0x84, 0x7D, 0x00,   // j
    0x00, 0x7F, 0x10, 0x28, 0x44, 0x00,   // k
    0x00, 0x00, 0x41, 0x7F, 0x40, 0x00,   // l
    0x00, 0x7C, 0x04, 0x18, 0x04, 0x78,   // m
    0x00, 0x7C, 0x08, 0x04, 0x04, 0x78,   // n
    0x00, 0x38, 0x44, 0x44, 0x44, 0x38,   // o
    0x00, 0xFC, 0x24, 0x24, 0x24, 0x18,   // p
    0x00, 0x18, 0x24, 0x24, 0x18, 0xFC,   // q
    0x00, 0x7C, 0x08, 0x04, 0x04, 0x08,   // r
    0x00, 0x48, 0x54, 0x54, 0x54, 0x20,   // s
    0x00, 0x04, 0x3F, 0x44, 0x40, 0x20,   // t
    0x00, 0x3C, 0x40, 0x40, 0x20, 0x7C,   // u
    0x00, 0x1C, 0x20, 0x40, 0x20, 0x1C,   // v
    0x00, 0x3C, 0x40, 0x30, 0x40, 0x3C,   // w
    0x00, 0x44, 0x28, 0x10, 0x28, 0x44,   // x
    0x00, 0x1C, 0xA0, 0xA0, 0xA0, 0x7C,   // y
    0x00, 0x44, 0x64, 0x54, 0x4C, 0x44,   // z
    0x14, 0x14, 0x14, 0x14, 0x14, 0x14    // horiz lines
};

const unsigned char BasicFont[][8] =
{
    {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
    {0x00,0x00,0x5F,0x00,0x00,0x00,0x00,0x00},
    {0x00,0x00,0x07,0x00,0x07,0x00,0x00,0x00},
    {0x00,0x14,0x7F,0x14,0x7F,0x14,0x00,0x00},
    {0x00,0x24,0x2A,0x7F,0x2A,0x12,0x00,0x00},
    {0x00,0x23,0x13,0x08,0x64,0x62,0x00,0x00},
    {0x00,0x36,0x49,0x55,0x22,0x50,0x00,0x00},
    {0x00,0x00,0x05,0x03,0x00,0x00,0x00,0x00},
    {0x00,0x1C,0x22,0x41,0x00,0x00,0x00,0x00},
    {0x00,0x41,0x22,0x1C,0x00,0x00,0x00,0x00},
    {0x00,0x08,0x2A,0x1C,0x2A,0x08,0x00,0x00},
    {0x00,0x08,0x08,0x3E,0x08,0x08,0x00,0x00},
    {0x00,0xA0,0x60,0x00,0x00,0x00,0x00,0x00},
    {0x00,0x08,0x08,0x08,0x08,0x08,0x00,0x00},
    {0x00,0x60,0x60,0x00,0x00,0x00,0x00,0x00},
    {0x00,0x20,0x10,0x08,0x04,0x02,0x00,0x00},
    {0x00,0x3E,0x51,0x49,0x45,0x3E,0x00,0x00},
    {0x00,0x00,0x42,0x7F,0x40,0x00,0x00,0x00},
    {0x00,0x62,0x51,0x49,0x49,0x46,0x00,0x00},
    {0x00,0x22,0x41,0x49,0x49,0x36,0x00,0x00},
    {0x00,0x18,0x14,0x12,0x7F,0x10,0x00,0x00},
    {0x00,0x27,0x45,0x45,0x45,0x39,0x00,0x00},
    {0x00,0x3C,0x4A,0x49,0x49,0x30,0x00,0x00},
    {0x00,0x01,0x71,0x09,0x05,0x03,0x00,0x00},
    {0x00,0x36,0x49,0x49,0x49,0x36,0x00,0x00},
    {0x00,0x06,0x49,0x49,0x29,0x1E,0x00,0x00},
    {0x00,0x00,0x36,0x36,0x00,0x00,0x00,0x00},
    {0x00,0x00,0xAC,0x6C,0x00,0x00,0x00,0x00},
    {0x00,0x08,0x14,0x22,0x41,0x00,0x00,0x00},
    {0x00,0x14,0x14,0x14,0x14,0x14,0x00,0x00},
    {0x00,0x41,0x22,0x14,0x08,0x00,0x00,0x00},
    {0x00,0x02,0x01,0x51,0x09,0x06,0x00,0x00},
    {0x00,0x32,0x49,0x79,0x41,0x3E,0x00,0x00},
    {0x00,0x7E,0x09,0x09,0x09,0x7E,0x00,0x00},
    {0x00,0x7F,0x49,0x49,0x49,0x36,0x00,0x00},
    {0x00,0x3E,0x41,0x41,0x41,0x22,0x00,0x00},
    {0x00,0x7F,0x41,0x41,0x22,0x1C,0x00,0x00},
    {0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x00},
    {0x00,0x7F,0x09,0x09,0x09,0x01,0x00,0x00},
    {0x00,0x3E,0x41,0x41,0x51,0x72,0x00,0x00},
    {0x00,0x7F,0x08,0x08,0x08,0x7F,0x00,0x00},
    {0x00,0x41,0x7F,0x41,0x00,0x00,0x00,0x00},
    {0x00,0x20,0x40,0x41,0x3F,0x01,0x00,0x00},
    {0x00,0x7F,0x08,0x14,0x22,0x41,0x00,0x00},
    {0x00,0x7F,0x40,0x40,0x40,0x40,0x00,0x00},
    {0x00,0x7F,0x02,0x0C,0x02,0x7F,0x00,0x00},
    {0x00,0x7F,0x04,0x08,0x10,0x7F,0x00,0x00},
    {0x00,0x3E,0x41,0x41,0x41,0x3E,0x00,0x00},
    {0x00,0x7F,0x09,0x09,0x09,0x06,0x00,0x00},
    {0x00,0x3E,0x41,0x51,0x21,0x5E,0x00,0x00},
    {0x00,0x7F,0x09,0x19,0x29,0x46,0x00,0x00},
    {0x00,0x26,0x49,0x49,0x49,0x32,0x00,0x00},
    {0x00,0x01,0x01,0x7F,0x01,0x01,0x00,0x00},
    {0x00,0x3F,0x40,0x40,0x40,0x3F,0x00,0x00},
    {0x00,0x1F,0x20,0x40,0x20,0x1F,0x00,0x00},
    {0x00,0x3F,0x40,0x38,0x40,0x3F,0x00,0x00},
    {0x00,0x63,0x14,0x08,0x14,0x63,0x00,0x00},
    {0x00,0x03,0x04,0x78,0x04,0x03,0x00,0x00},
    {0x00,0x61,0x51,0x49,0x45,0x43,0x00,0x00},
    {0x00,0x7F,0x41,0x41,0x00,0x00,0x00,0x00},
    {0x00,0x02,0x04,0x08,0x10,0x20,0x00,0x00},
    {0x00,0x41,0x41,0x7F,0x00,0x00,0x00,0x00},
    {0x00,0x04,0x02,0x01,0x02,0x04,0x00,0x00},
    {0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00},
    {0x00,0x01,0x02,0x04,0x00,0x00,0x00,0x00},
    {0x00,0x20,0x54,0x54,0x54,0x78,0x00,0x00},
    {0x00,0x7F,0x48,0x44,0x44,0x38,0x00,0x00},
    {0x00,0x38,0x44,0x44,0x28,0x00,0x00,0x00},
    {0x00,0x38,0x44,0x44,0x48,0x7F,0x00,0x00},
    {0x00,0x38,0x54,0x54,0x54,0x18,0x00,0x00},
    {0x00,0x08,0x7E,0x09,0x02,0x00,0x00,0x00},
    {0x00,0x18,0xA4,0xA4,0xA4,0x7C,0x00,0x00},
    {0x00,0x7F,0x08,0x04,0x04,0x78,0x00,0x00},
    {0x00,0x00,0x7D,0x00,0x00,0x00,0x00,0x00},
    {0x00,0x80,0x84,0x7D,0x00,0x00,0x00,0x00},
    {0x00,0x7F,0x10,0x28,0x44,0x00,0x00,0x00},
    {0x00,0x41,0x7F,0x40,0x00,0x00,0x00,0x00},
    {0x00,0x7C,0x04,0x18,0x04,0x78,0x00,0x00},
    {0x00,0x7C,0x08,0x04,0x7C,0x00,0x00,0x00},
    {0x00,0x38,0x44,0x44,0x38,0x00,0x00,0x00},
    {0x00,0xFC,0x24,0x24,0x18,0x00,0x00,0x00},
    {0x00,0x18,0x24,0x24,0xFC,0x00,0x00,0x00},
    {0x00,0x00,0x7C,0x08,0x04,0x00,0x00,0x00},
    {0x00,0x48,0x54,0x54,0x24,0x00,0x00,0x00},
    {0x00,0x04,0x7F,0x44,0x00,0x00,0x00,0x00},
    {0x00,0x3C,0x40,0x40,0x7C,0x00,0x00,0x00},
    {0x00,0x1C,0x20,0x40,0x20,0x1C,0x00,0x00},
    {0x00,0x3C,0x40,0x30,0x40,0x3C,0x00,0x00},
    {0x00,0x44,0x28,0x10,0x28,0x44,0x00,0x00},
    {0x00,0x1C,0xA0,0xA0,0x7C,0x00,0x00,0x00},
    {0x00,0x44,0x64,0x54,0x4C,0x44,0x00,0x00},
    {0x00,0x08,0x36,0x41,0x00,0x00,0x00,0x00},
    {0x00,0x00,0x7F,0x00,0x00,0x00,0x00,0x00},
    {0x00,0x41,0x36,0x08,0x00,0x00,0x00,0x00},
    {0x00,0x02,0x01,0x01,0x02,0x01,0x00,0x00},
    {0x00,0x02,0x05,0x05,0x02,0x00,0x00,0x00}
};



//           12345678901234567890
const char chaine0[]="18F87J50 Clicker2: Test OLED C SEPS114A 96x96 65K colors\r\n ";
const char chaine1[]="Q=8MHZ x PLL => 48MHz  \r\n";
const char chaine2[]="............ \r\n";
const char chaine3[]="Projet: Oled_C_18F87J50.mcppi\r\n";
const char chaine4[]="Attente Init liaison HID Terminal \r\n";
const char *RS_Str[]={chaine0,chaine1,chaine2,chaine3,chaine4};

#define MAXLEN1 80
unsigned char buffer1[MAXLEN1];
unsigned int Index1,i1;
unsigned int UART1_DataReady;
unsigned char c1;


char TEXTE[64];
char CRam1[24];
char *txt;
unsigned int i,j,k;

volatile unsigned int Flag_Timer0;
volatile unsigned int Cpt0;
unsigned int EAx,EA0;

unsigned long Fr;
float f1,f2;


 void Interrupts() iv 0x0008 ics ICS_AUTO
{
 //   ====  IT Timer0  =============
   if((TMR0IE_bit==1) && (TMR0IF_bit==1))
   {
     Cpt0++;
    if(Cpt0>19)
     {
      Flag_Timer0=1;
      T0CON.TMR0ON=0;
      TMR0IE_bit=0;
      Cpt0=0;
      }
     INTCON.T0IF=0; // Raz Flag
   }
     USB_Interrupt_Proc();
}


void OLED_C_command(unsigned char reg_index, unsigned char reg_value);

// --- Copie le texte depuis ROM vers RAM
void strConstRamCpy(char *dest, const char *source) {
  while(*source) *dest++ = *source++ ;
  *dest = 0 ;    // terminateur
}

 void Init_Timer0()
{
 //--- init timer0 en mode 16 bits
 //see PIC18F25K22_46K22_41412E.pdf  11.11 page 159
  T0CON.PSA=0;      // Timer0 prescaler assigned to Clock
  T0CON.T0PS2=1;    //
  T0CON.T0PS1=0;    //
  T0CON.T0PS0=0;    // prescler =>100 => 1/32
  T0CON.T0CS=0;     // internal cycle clock
  T0CON.T08BIT=0 ;  // Mode 16 bits
    // 100msec at 48MHz et prescaler=32
  TMR0H= 0x6D; // hi 28036;
  TMR0L =0x84 ; // Lo 28036;
// 18661 prescaler =256 1sec at 48MHz  48E5
// 28036 prescaler=32 48MHz => 100mS  6D84
// 3035 prescaler =128  0,5sec @64Mhz
// 3035  prescaler=128  2sec at 16Mhz
// 34286  prescaler=128  1,0sec at 16Mhz    85EE
// 26456   prescaler=128 1sec at 20Mhz
  INTCON.TMR0IF=0;    // raz flag interrupt
  Cpt0=0;
  Flag_Timer0=0;
  INTCON2.TMR0IP=1;
  INTCON.TMR0IE=1;
  T0CON.TMR0ON=1;
}


void Init_ADC()
 {
       //config lecture ADC 10 bits

  ADCON0.VCFG1=0;  // - AVss=Gnd;
  ADCON0.VCFG0=0;  // +Avdd;
  ADCON0.CHS3=0;  // channel 0
  ADCON0.CHS2=0;
  ADCON0.CHS1=0;
  ADCON0.CHS0=0;
  ADCON0.ADON=1;      // ADC enabled
  ADCON0=1;

  ADCON1.ADFM=1;     // right justified
  ADCON1.ADCAL=0;
  ADCON1.ACQT2=1;
  ADCON1.ACQT1=1;
  ADCON1.ACQT0=0;    // 110=> 16 TAD
  ADCON1.ADCS1=1;
  ADCON1.ADCS2=1;
  ADCON1.ADCS0=0;    // 110 => Fosc/64
 }


 void Hardware_Init(void)
 {

  ANCON0=0xFE ; // ANO= analog  others as I/O
  ANCON1=0xFF; // No analog on AN15--AN10
  TRISA=0xFF;
  TRISC=0xFF;
  TRISG=0xFF;

   #ifdef OLED
  OLED_RW_Direction=0; // RA1 ou RA0
  OLED_RST_Direction=0; //RD0 ou RD2
  OLED_CS_Direction=0; //RD1  ou RD3
  OLED_DC_Direction=0; //RG0  ou RG3
  OLED_RW=0; // RA1 ou RA0
  OLED_RST=0; //RD0 ou RD2
  OLED_CS=0; //RD1  ou RD3
  OLED_DC=0; //RG0  ou RG3
  #endif

  BP1_Direction = 1;         // Set direction for buttons
  BP2_Direction = 1;
  LD1_Direction = 0;        // Set direction for LEDs
  LD2_Direction = 0;
  LD1 = 0;                  // turn off LEDs
  LD2 = 0;
  }


  void Test_2_leds()
{
  LD1 = 0;                  // turn off LEDs
  LD2 = 0;
  Delay_ms(500);
  LD1 = 1;
  Delay_ms(500);
  LD1 = 0;
  LD2 = 1;
  Delay_ms(500);
  LD1 = 1;
  LD2 = 0;
  Delay_ms(500);
  LD1 = 0;
  LD2 = 0;
  }
  
 void Test_LED2()
{

  LD2 = 1;
  Delay_ms(500);
  LD2 = 0;
  Delay_ms(500);
  LD2 = 1;
  Delay_ms(500);
  LD2 = 0;
  Delay_ms(500);
  LD2 = 1;
   Delay_ms(500);
  LD2 = 0;
  }

void Test_LED1()
{

  LD1 = 1;
  Delay_ms(1000);
  LD1 = 0;
  Delay_ms(1000);
  LD1 = 1;
  Delay_ms(1000);
  LD1 = 0;
  }

  #ifdef OLED
  
/*

void OLED_write(unsigned char value, unsigned char type)
{
    unsigned char s = 0x08;
    switch(type)
    {
        case 1: { DC = 1;    break;}
        case 0: {  DC = 0;    break;  }
    }
    SPI1_Write(value);

}

  

void OLED_gotoxy(unsigned char x_pos, unsigned char y_pos)
{
    OLED_write((Set_Page_Start_Address_CMD + y_pos), CMD);
    OLED_write(((x_pos & 0x0F) | Set_Lower_Column_Start_Address_CMD), CMD);
    OLED_write((((x_pos & 0xF0) >> 0x04) | Set_Higher_Column_Start_Address_CMD), CMD);
}



void OLED_print_char(unsigned char x_pos, unsigned char y_pos, unsigned char ch)
{
    unsigned char chr = 0x00;
    unsigned char s = 0x00;
    chr = (ch - 32);
    if(x_pos > (x_max - 6))
    {
        x_pos = 0;
        y_pos++;
    }
    OLED_gotoxy(x_pos, y_pos);

    for(s = 0x00; s < 0x06; s++)
    {
        OLED_write(font_regular[chr][s], DAT);
    }
}

*/
  
  
 //***************************************

//Send command to OLED C display
void OLED_C_command(unsigned char reg_index, unsigned char reg_value){
//Select index addr
    OLED_CS = 0;
    OLED_DC = 0;
    SPI1_Write(reg_index);
    OLED_CS = 1;
//Write data to reg
    OLED_CS = 0;
    OLED_DC = 1;
    SPI1_Write(reg_value);
    OLED_CS = 1;
}

//Send data to OLED C display
void OLED_C_data(unsigned char data_value){
    OLED_CS = 0;
    OLED_DC = 1;
    SPI1_Write(data_value);
    OLED_CS = 1;
}

// Init sequence for 96x96 OLED color module
void OLED_C_Init()
{
   OLED_RST=0;
   Delay_ms(10);
   OLED_RST=1;
   Delay_ms(10);
  //  Soft reset
  OLED_C_command(S_SOFT_RESET,0x00);
     // Standby ON/OFF
   OLED_C_command(S_STANDBY_ON_OFF,0x01);   // Standby on
   Delay_ms(5);             // Wait for 5ms (1ms Delay Minimum)
   OLED_C_command(S_STANDBY_ON_OFF,0x00);   // Standby off
   Delay_ms(5);             // 1ms Delay Minimum (1ms Delay Minimum)
   /* Display OFF */
   OLED_C_command(S_DISPLAY_ON_OFF,0x00);
   /* Set Oscillator operation */
   OLED_C_command(S_ANALOG_CONTROL,0x00);   // using external resistor and internal OSC
   /* Set frame rate */
   OLED_C_command(S_OSC_ADJUST,0x03);       // frame rate : 95Hz
   /* Set active display area of panel */
   OLED_C_command(S_DISPLAY_X1,0x00);
   OLED_C_command(S_DISPLAY_X2,0x5F);
   OLED_C_command(S_DISPLAY_Y1,0x00);
   OLED_C_command(S_DISPLAY_Y2,0x5F);
   /* Select the RGB data format and set the initial state of RGB interface port */
   OLED_C_command(S_RGB_IF,0x00);       // RGB 8bit interface
   /* Set RGB polarity */
   OLED_C_command(S_RGB_POL,0x00);
   /* Set display mode control */
   OLED_C_command(S_DISPLAY_MODE_CONTROL,0x80);  // SWAP:BGR, Reduce current : Normal, DC[1:0] : Normal
   /* Set MCU Interface */
   OLED_C_command(S_CPU_IF,0x00);        // MPU External interface mode, 8bits
   /* Set Memory Read/Write mode */
   OLED_C_command(S_MEMORY_WRITE_READ,0x00);
   /* Set row scan direction */
   OLED_C_command(S_ROW_SCAN_DIRECTION,0x00);     // Column : 0 --> Max, Row : 0 --> Max
   /* Set row scan mode */
   OLED_C_command(S_ROW_SCAN_MODE,0x00);      // Alternate scan mode
   /* Set column current */
   OLED_C_command(S_COLUMN_CURRENT_R,0x6E);
   OLED_C_command(S_COLUMN_CURRENT_G,0x4F);
   OLED_C_command(S_COLUMN_CURRENT_B,0x77);
   /* Set row overlap */
   OLED_C_command(S_ROW_OVERLAP,0x00);    // Band gap only
   /* Set discharge time */
   OLED_C_command(S_DISCHARGE_TIME,0x01);     // Discharge time : normal discharge
   /* Set peak pulse delay */
   OLED_C_command(S_PEAK_PULSE_DELAY,0x00);
   /* Set peak pulse width */
   OLED_C_command(S_PEAK_PULSE_WIDTH_R,0x02);
   OLED_C_command(S_PEAK_PULSE_WIDTH_G,0x02);
   OLED_C_command(S_PEAK_PULSE_WIDTH_B,0x02);
   /* Set precharge current */
   OLED_C_command(S_PRECHARGE_CURRENT_R,0x14);
   OLED_C_command(S_PRECHARGE_CURRENT_G,0x50);
   OLED_C_command(S_PRECHARGE_CURRENT_B,0x19);
   /* Set row scan on/off  */
   OLED_C_command(S_ROW_SCAN_ON_OFF,0x00);    // Normal row scan
   /* Set scan off level */
   OLED_C_command(S_SCAN_OFF_LEVEL,0x04);     // VCC_C*0.75
   /* Set memory access point */
   OLED_C_command(S_DISPLAYSTART_X,0x00);
   OLED_C_command(S_DISPLAYSTART_Y,0x00);
   /* Display ON */
   OLED_C_command(S_DISPLAY_ON_OFF,0x01);
}

//Sequence before writing data to memory
void DDRAM_access()
{
    OLED_CS=0;
    OLED_DC=0;
    SPI1_Write(0x08);
    OLED_CS=1;
}

//Set memory area(address) to write a display data
void OLED_C_MemorySize(char X1, char X2, char Y1, char Y2){
    OLED_C_command(S_MEM_X1,X1);
    OLED_C_command(S_MEM_X2,X2);
    OLED_C_command(S_MEM_Y1,Y1);
    OLED_C_command(S_MEM_Y2,Y2);
}

//Select color
void OLED_C_Color(char colorMSB, char colorLSB ){
    OLED_C_data(colorMSB);
    OLED_C_data(colorLSB);
}

void OLED_C_Background()
{
    unsigned i,j,k;
    OLED_C_command(0x1D,0x02);  //Set Memory Read/Write mode
    OLED_C_MemorySize(0x00,0x5F,0x00,0x5F);
    DDRAM_access();
    for(j=0;j<9216;j++)
    {
       OLED_C_Color(0xFF,0xFF);
    }
    //delay_ms(1000);
    
    OLED_C_MemorySize(0x05,0x5A,0x05,0x5A);
    DDRAM_access();
    for(j=0;j<8100;j++)
    {
      OLED_C_Color(0x0C,0xC0);
    }
    Delay_ms(1000);
     
    OLED_C_MemorySize(0x0A,0x55,0x0A,0x55);
    DDRAM_access();
    for(j=0;j<7225;j++)
    {
         OLED_C_Color(0xFF,0x00);
    }
    Delay_ms(1000);
                       
    OLED_C_MemorySize(0x0F,0x50,0x0F,0x50);
    DDRAM_access();
    for(j=0;j<6400;j++)
    {
      OLED_C_Color(0x80,0x00);
    }
    // Delay_ms(1000);
    OLED_C_MemorySize(0x14,0x4B,0x14,0x4B);
    DDRAM_access();
    for(j=0;j<5625;j++)
    {
      OLED_C_Color(0xF8,0x00);
    }
    Delay_ms(1000);
    OLED_C_MemorySize(0x19,0x46,0x19,0x46);
    DDRAM_access();
    for(j=0;j<4900;j++)
    {
     OLED_C_Color(0x00,0xFF);
    }
    // Delay_ms(1000);
    OLED_C_MemorySize(0x1E,0x41,0x1E,0x41);
    DDRAM_access();
    for(j=0;j<4225;j++)
    {
       OLED_C_Color(0x80,0xFF);
    }
    Delay_ms(5000);
}
#endif     // OLED

void CRLF_HID()
{
  *(&writebuff)=13;
    *(&writebuff+1)=10;
      *(&writebuff+2)=0;
  while(!HID_Write(&writebuff,64));
 }

void main()
{
  Hardware_Init();
  Delay_ms(2000);

  TEXTE[0]=0;
  CRam1[0]=0;
  txt=&TEXTE[0];
  
  Test_2_leds();
  
  HID_Enable(&readbuff,&writebuff);      // Enable HID communication
  CRLF_HID();
   Delay_ms(2000);
   
  Test_LED1();
  
  strConstRamCpy( &writebuff,Version"\r\n");
   while(!HID_Write(&writebuff,64)) ;
   CRLF_HID();
   
   strConstRamCpy( &writebuff,"OLED sur mikroBus #2\r\n");
   while(!HID_Write(&writebuff,64)) ;
   CRLF_HID();

   strcpy( &writebuff,*chaine0);
   while(!HID_Write(&writebuff,64)) ;
   strcpy( &writebuff,*chaine1);
   while(!HID_Write(&writebuff,64)) ;
   Delay_ms(5000);
   
   Test_LED2()  ;
   
  #ifdef OLED
  // Initialize SPI3 module
  //SPI1_Init_Advanced(_SPI_MASTER_OSC_DIV64, _SPI_DATA_SAMPLE_MIDDLE, _SPI_CLK_IDLE_LOW, _SPI_LOW_2_HIGH);
  //
  SPI1_Init();
  Delay_ms(200);

  OLED_C_Init();
  OLED_C_Background();
  #endif
  
  Init_ADC();
  strConstRamCpy( &writebuff,"Int ADC ch0 \r\n ");
  while(!HID_Write(&writebuff,64));
  
  RC1IE_bit = 0;          //disable Rx1 intterupts
  RC2IE_bit = 0;          // disable Rx2 intterupts
  PEIE_bit = 1;           // Enable peripheral interrupts
  GIE_bit  = 1;           // Enable global interrupts
  Cpt0=0;
  Init_Timer0();
  

  while(1)
  {
  #ifdef OLED
     for(i=0;i<8;i++)
     {
       OLED_C_command(S_SCREEN_SAVER_MODE,i);
       OLED_C_command(S_SCREEN_SAVER_CONTEROL,0x88);
       Delay_ms(500);
       OLED_C_command(S_SCREEN_SAVER_CONTEROL,0x00);
    }
    #endif
   // waiting for COM or Timeout
   Init_Timer0();
   while(!HID_Read() && (Flag_Timer0==0));                  // wait for data on USB
   if(Flag_Timer0==1)
   {
    Init_Timer0();
    }
   else
   {
       k=strlen(&readbuff);
       strcpy( txt,&readbuff);
       strConstRamCpy( &writebuff,"Reception de: ");
       while(!HID_Write(&writebuff,64));
       strcpy( &writebuff,txt);
       while(!HID_Write(&writebuff,64));
       CRLF_HID();
        if(strncmp(&readbuff,"LD1_ON",6)==0 )
        {
          LD1=1;
           strConstRamCpy( &writebuff,"Fire LD1\r\n");
           while(!HID_Write(&writebuff,64));
         }
        if(strncmp(&readbuff,"LD1_OFF",7)==0 )
        {
          LD1=0;
            strConstRamCpy( &writebuff,"Shutdown LD1\r\n");
            while(!HID_Write(&writebuff,64));
         }
        if(strncmp(&readbuff,"LD2_ON",6)==0)
        {
           LD2=1;
           strConstRamCpy( &writebuff,"Fire LD2\r\n");
           while(!HID_Write(&writebuff,64));
         }
        if(strncmp(&readbuff,"LD2_OFF",7)==0)
        {
            LD2=0;
             strConstRamCpy( &writebuff,"Shutdown LD2\r\n");
            while(!HID_Write(&writebuff,64));
         }
     }
    EA0=ADC_Read(0);
    WordToStr(EA0,CRam1);
    strConstRamCpy( &writebuff,"EA0 = .... ");
    k=strlen(CRam1);
    *(CRam1+k)=13; *(CRam1+k+1)=10; *(CRam1+k+2)=0;
    strcpy(&writebuff+6,CRam1);
    while(!HID_Write(&writebuff,64));
    
    
    OLED_C_command(S_DISPLAY_ON_OFF,0x00);
//Set memory area(address) to write a display data
    OLED_C_MemorySize(0x0A,0x5A,0x30,0x31);
      DDRAM_access();
//Select color
    for(j=0;j<0x5F;j++)
    {
      OLED_C_Color(0x0F,0xF0);
    }
      OLED_C_command(S_DISPLAY_ON_OFF,0x01);
     Delay_ms(2000);
   }
 }

 
 /*
 0 1 mikroCPIC1618.exe -MSF -DBG -pP18F87J50 -RA -C -O11111004 -fo48 -N"C:\_MikroC\_MesProjets_MikroC\_Oled_click\Oled_C_18F87J50.mcppi" -SP"C:\_MikroC\mikroC PRO for PIC\defs\" -SP"C:\_MikroC\mikroC PRO for PIC\uses\P18\" -SP"C:\_MikroC\_MesProjets_MikroC\_Oled_click\" -SP"C:\_MikroC\_MesProjets_MikroC\__18F87J50_Clicker2\" -IP"C:\_MikroC\_MesProjets_MikroC\_Oled_click\" "Oled_C_18F87J50_150731.c" "USBdsc_1507.c" "__Lib_Math.mcl" "__Lib_MathDouble.mcl" "__Lib_System.mcl" "__Lib_Delays.mcl" "__Lib_CType.mcl" "__Lib_CString.mcl" "__Lib_CStdlib.mcl" "__Lib_Conversions.mcl" "__Lib_ADC_87J50.mcl" "__Lib_SPI_c345d654.mcl" "__Lib_USB_genHID_P18FJ.mcl" "__Lib_PortExpander.mcl" "__Lib_GlcdFonts.mcl" "__Lib_SPIGlcd.mcl"
0 1139 Available RAM: 3883 [bytes], Available ROM: 131064 [bytes]
0 122 Compilation Started P18F87J50.c
3055 123 Compiled Successfully P18F87J50.c
0 122 Compilation Started __Lib_Delays.c
172 123 Compiled Successfully __Lib_Delays.c
0 122 Compilation Started __Lib_GlcdFonts.c
1207 123 Compiled Successfully __Lib_GlcdFonts.c
0 122 Compilation Started Oled_C_18F87J50_150731.c
0 1004 interrupt handler (Interrupts at 0x0008) Oled_C_18F87J50_150731.c
643 1163 Variable 'i' has been declared, but not used Oled_C_18F87J50_150731.c
643 1163 Variable 'k' has been declared, but not used Oled_C_18F87J50_150731.c
837 123 Compiled Successfully Oled_C_18F87J50_150731.c
0 122 Compilation Started USBdsc_1507.c
166 123 Compiled Successfully USBdsc_1507.c
0 127 All files Compiled in 94 ms
0 1144 Used RAM (bytes): 411 (11%)  Free RAM (bytes): 3472 (89%) Used RAM (bytes): 411 (11%)  Free RAM (bytes): 3472 (89%)
0 1144 Used ROM (bytes): 10166 (8%)  Free ROM (bytes): 120898 (92%) Used ROM (bytes): 10166 (8%)  Free ROM (bytes): 120898 (92%)
0 125 Project Linked Successfully Oled_C_18F87J50.mcppi
0 128 Linked in 62 ms
0 129 Project 'Oled_C_18F87J50.mcppi' completed: 344 ms
0 103 Finished successfully: 31 juil. 2015, 15:44:43 Oled_C_18F87J50.mcppi
*/